searchData={"items":[{"type":"module","title":"ExFTMS","doc":"Documentation for `ExFTMS`.","ref":"ExFTMS.html"},{"type":"function","title":"ExFTMS.advertising_data/1","doc":"Returns a AD binary (length - type - value) as defined in the FTMS spec.\nSimply include this in your advertising data.\n\nThis LTV takes up 7 bytes.\n\n`type` is the fitness machine type (`:treadmill`, `:cross_trainer`, ...)\n\n    iex> ExFTMS.advertising_data(:stair_climber)\n    <<6, 22, 38, 24, 1, 8, 0>>\n\n    iex> ExFTMS.advertising_data(:stair_climber) |> Base.encode16()\n    \"06162618010800\"","ref":"ExFTMS.html#advertising_data/1"},{"type":"function","title":"ExFTMS.fitness_machine_features/2","doc":"Get the value needed for the Fitness Machine Features characteristic\nby passing a sample of your data.\n\n`sample_data` is one of\n\n* `%ExFTMS.StairClimberData{}`\n\nwith all fields that your machine supports set to some non-nil value.\n\nThis characteristic tells clients what data they can expect to receive from the fitness machine.\nNote: `ExFTMS` currently does not support target setting.\n\n    iex> %ExFTMS.StairClimberData{\n    ...>   elapsed_time: 1,\n    ...>   met: 1,\n    ...>   hr: 1,\n    ...>   energy_per_minute: :data_not_available,\n    ...>   energy_per_hour: 1,\n    ...>   total_energy: 1,\n    ...>   stride_count: 0,\n    ...>   elevation_gain: 0,\n    ...>   avg_step_rate: 20,\n    ...>   spm: 20,\n    ...>   floors: 0\n    ...> }\n    ...> |> ExFTMS.fitness_machine_features()\n    ...> |> Base.encode16()\n    \"501F000000000000\"","ref":"ExFTMS.html#fitness_machine_features/2"},{"type":"type","title":"ExFTMS.training_status/0","doc":"","ref":"ExFTMS.html#t:training_status/0"},{"type":"function","title":"ExFTMS.training_status/1","doc":"Get the value needed for the Training Status characteristic.\n  Training Status String/Extended String not supported currently.\n\n    iex> ExFTMS.training_status(:manual_mode)\n    <<0, 13>>\n\n    iex> ExFTMS.training_status(:manual_mode) |> Base.encode16()\n    \"000D\"","ref":"ExFTMS.html#training_status/1"},{"type":"module","title":"ExFTMS.FitnessMachineStatus","doc":"The Fitness Machine Status characteristic is only needed if the server supports\nthe Fitness Machine Control Point characteristic. Then it's used to communicate\nthe status of the server.","ref":"ExFTMS.FitnessMachineStatus.html"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.control_permission_lost/0","doc":"Client has lost controlled: revoked by the user or another client has requested control.","ref":"ExFTMS.FitnessMachineStatus.html#control_permission_lost/0"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.indoor_bike_simulation_parameters_changed/4","doc":"Indoor Bike Simulation Parameters\n\n* wind_speed: m/s\n* grade: percentage\n* crr: unitless coefficient of rolling resistance\n* cw: kg/m wind resistance coefficient","ref":"ExFTMS.FitnessMachineStatus.html#indoor_bike_simulation_parameters_changed/4"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.paused/0","doc":"","ref":"ExFTMS.FitnessMachineStatus.html#paused/0"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.reset/0","doc":"","ref":"ExFTMS.FitnessMachineStatus.html#reset/0"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.spin_down_status/1","doc":"Spin down status can be one of [:spin_down_requested, :success, :error, :stop_pedaling] or\nthe raw value if you need to set a custom value (0-255).\n\n    iex> ExFTMS.FitnessMachineStatus.spin_down_status(:success)\n    <<0x14, 0x02>>","ref":"ExFTMS.FitnessMachineStatus.html#spin_down_status/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.started_or_resumed/0","doc":"If you don't want to bother with anything else, at least send this when the\nmachine is running.\n\n    iex> ExFTMS.FitnessMachineStatus.started_or_resumed() |> Base.encode16()\n    \"04\"","ref":"ExFTMS.FitnessMachineStatus.html#started_or_resumed/0"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.stopped/0","doc":"","ref":"ExFTMS.FitnessMachineStatus.html#stopped/0"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.stopped_by_safety_key/0","doc":"","ref":"ExFTMS.FitnessMachineStatus.html#stopped_by_safety_key/0"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.target_heart_rate_changed/1","doc":"Heart rate in beats per minute (BPM)\n\n    iex> ExFTMS.FitnessMachineStatus.target_heart_rate_changed(150)\n    <<0x09, 150>>","ref":"ExFTMS.FitnessMachineStatus.html#target_heart_rate_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.target_incline_changed/1","doc":"Incline percent should be passed as a float from 0.0 to 1.0, so 1.5% incline would be 0.015.\n\n    iex> ExFTMS.FitnessMachineStatus.target_incline_changed(0.037) # 3.7 % incline\n    <<0x06, 37, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#target_incline_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.target_power_changed/1","doc":"Power in Watt\n\n    iex> ExFTMS.FitnessMachineStatus.target_power_changed(5)\n    <<8, 5, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#target_power_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.target_resistance_level_changed/1","doc":"Resistance level as a float, e.g. 3.4\n\n    iex> ExFTMS.FitnessMachineStatus.target_resistance_level_changed(5.0)\n    <<7, 50>>","ref":"ExFTMS.FitnessMachineStatus.html#target_resistance_level_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.target_speed_changed/1","doc":"Speed should be passed in km/h.\n\n    iex> ExFTMS.FitnessMachineStatus.target_speed_changed(3.7)\n    <<0x05, 37, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#target_speed_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_cadence_changed/1","doc":"Cadence (e.g. RPM on an indoor bike)\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_cadence_changed(90)\n    <<0x15, 180, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_cadence_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_distance_changed/1","doc":"Distance in meters\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_distance_changed(50)\n    <<0x0D, 50, 0, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_distance_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_expended_energy_changed/1","doc":"Targeted expended energy in calories\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_expended_energy_changed(250)\n    <<0x0A, 250, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_expended_energy_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_steps_changed/1","doc":"Steps\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_steps_changed(255)\n    <<0x0B, 255, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_steps_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_strides_changed/1","doc":"Strides\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_strides_changed(255)\n    <<0x0C, 255, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_strides_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_training_time_changed/1","doc":"Training time in seconds\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_training_time_changed(120)\n    <<0x0E, 120, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_training_time_changed/1"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_training_time_in_five_heart_rate_zones_changed/5","doc":"Pass the times for the five zones in full seconds\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_training_time_in_five_heart_rate_zones_changed(1, 2, 3, 4, 5)\n    <<0x11, 1, 0, 2, 0, 3, 0, 4, 0, 5, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_training_time_in_five_heart_rate_zones_changed/5"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_training_time_in_three_heart_rate_zones_changed/3","doc":"Pass the times for the three zones in full seconds\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_training_time_in_three_heart_rate_zones_changed(10, 3, 1)\n    <<0x10, 10, 0, 3, 0, 1, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_training_time_in_three_heart_rate_zones_changed/3"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.targeted_training_time_in_two_heart_rate_zones_changed/2","doc":"Pass the times for the two zones in full seconds\n\n    iex> ExFTMS.FitnessMachineStatus.targeted_training_time_in_two_heart_rate_zones_changed(10, 3)\n    <<15, 10, 0, 3, 0>>","ref":"ExFTMS.FitnessMachineStatus.html#targeted_training_time_in_two_heart_rate_zones_changed/2"},{"type":"function","title":"ExFTMS.FitnessMachineStatus.wheel_circumference_changed/1","doc":"Circumference in Millimeters with resolution of 0.1 Millimeter, 0.1 == 1\n\n    iex> ExFTMS.FitnessMachineStatus.wheel_circumference_changed(280)\n    <<0x13, 240, 10>>","ref":"ExFTMS.FitnessMachineStatus.html#wheel_circumference_changed/1"},{"type":"module","title":"ExFTMS.StairClimberData","doc":"Documentation for `StairClimberData`.","ref":"ExFTMS.StairClimberData.html"},{"type":"function","title":"ExFTMS.StairClimberData.decode/2","doc":"Decodes the input binary of stair climber data into a `StairClimberData` struct.\nReturns `{:ok, data}` if parsing is successful, or `:error` if parsing fails.\n\nIf you have a Base16 encoded string (hex values from e.g. nRF Connect) then use `Base.decode16/1` first.","ref":"ExFTMS.StairClimberData.html#decode/2"},{"type":"function","title":"ExFTMS.StairClimberData.decode!/2","doc":"Same as `decode/1`, but returns the data directly,\nor raises a `ParseError` exception if there is bad input data.","ref":"ExFTMS.StairClimberData.html#decode!/2"},{"type":"function","title":"ExFTMS.StairClimberData.encode/2","doc":"Encodes a `%StairClimberData{}` into a list of binary notifications, length 1 or more.\nSend the list in the order of head first, the final binary will have the more data flag set to 0.\n\nSee `4.19 Transmission of a Data Record` in the FTMS spec.","ref":"ExFTMS.StairClimberData.html#encode/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}